.card
    background-color: white
    box-shadow: 0px 1px 2px grey
    overflow: auto

    .card-title
        margin-bottom: 20px
        border-bottom: 1px solid #c8c8c8
        padding-bottom: 20px
        padding-left: 10px
        font-weight: bold
        color: #595959
        font-size: 1.5rem

    &>label
        border-bottom: 1px solid #c8c8c8
        padding: 10px 30px
        font-weight: bold
        font-size: 1.5rem
        display: block
        background-color: #4e6eaa
        color: white
        line-height: 1.5rem


.p-input-materialize
    input
        border: none
        width: 100%